@@ -21,8 +21,8 @@
 #include <tqspinbox.h>
 
 #include <kcolorbutton.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 
 #include "kdirtreeview.h"
 #include "ktreemapview.h"
@@ -201,7 +201,7 @@ KTreeColorsPage::KTreeColorsPage( KSettingsDialog *	dialog,
     }
 
 
-    //Qt::Vertical slider
+    // Vertical slider
 
     _slider = new TQSlider( 1,			// minValue
 			   _maxButtons,		// maxValue
@@ -502,7 +502,7 @@ KCleanupListBoxItem::KCleanupListBoxItem( KCleanupListBox *	listBox,
     : TQListBoxText( listBox )
     , _cleanup( cleanup )
 {
-    CHECK_PTR( cleanup );
+    TQ_CHECK_PTR( cleanup );
     setText( cleanup->cleanTitle() );
 }
 
@@ -572,7 +572,7 @@ KCleanupPropertiesPage::KCleanupPropertiesPage( TQWidget *	parent,
     label = new TQLabel( i18n( "%n File / Directory Name Without Path" ), _fields );
     grid->addWidget( label, 3, 1 );
 
-    label = new TQLabel( i18n( "%t KDE Trash Directory" ), _fields );
+    label = new TQLabel( i18n( "%t TDE Trash Directory" ), _fields );
     grid->addWidget( label, 4, 1 );
 
 
@@ -740,7 +740,7 @@ KGeneralSettingsPage::~KGeneralSettingsPage()
 void
 KGeneralSettingsPage::apply()
 {
-    KConfig * config = kapp->config();
+    TDEConfig * config = kapp->config();
 
     config->setGroup( "Directory Reading" );
     config->writeEntry( "CrossFileSystems",	_crossFileSystems->isChecked()		);
@@ -769,7 +769,7 @@ KGeneralSettingsPage::revertToDefaults()
 void
 KGeneralSettingsPage::setup()
 {
-    KConfig * config = kapp->config();
+    TDEConfig * config = kapp->config();
     config->setGroup( "Directory Reading" );
 
     _crossFileSystems->setChecked	( config->readBoolEntry( "CrossFileSystems"	, false) );
@@ -932,7 +932,7 @@ KTreemapPage::~KTreemapPage()
 void
 KTreemapPage::apply()
 {
-    KConfig * config = kapp->config();
+    TDEConfig * config = kapp->config();
 
     config->setGroup( "Treemaps" );
 
@@ -982,7 +982,7 @@ KTreemapPage::revertToDefaults()
 void
 KTreemapPage::setup()
 {
-    KConfig * config = kapp->config();
+    TDEConfig * config = kapp->config();
     config->setGroup( "Treemaps" );
 
     _squarify->setChecked		( config->readBoolEntry( "Squarify"		, true	) );
@@ -1024,7 +1024,7 @@ KTreemapPage::checkEnabledState()
 
 
 TQColor
-KTreemapPage::readColorEntry( KConfig * config, const char * entryName, TQColor defaultColor )
+KTreemapPage::readColorEntry( TDEConfig * config, const char * entryName, TQColor defaultColor )
 {
     return config->readColorEntry( entryName, &defaultColor );
 }
@@ -1052,5 +1052,5 @@ addVStretch( TQWidget * parent )
 					 1 ) );				// vstretch
 }
 
-
+#include "kdirstatsettings.moc"
 // EOF
