@@ -14,9 +14,9 @@
 #include <tqregexp.h>
 
 #include <kapp.h>
-#include <kconfig.h>
-#include <kglobal.h>
-#include <klocale.h>
+#include <tdeconfig.h>
+#include <tdeglobal.h>
+#include <tdelocale.h>
 
 #include "kdirtree.h"
 #include "ktreemapview.h"
@@ -115,7 +115,7 @@ KTreemapView::deleteAllItems( TQCanvas * canvas )
 void
 KTreemapView::readConfig()
 {
-    KConfig * config = kapp->config();
+    TDEConfig * config = kapp->config();
     config->setGroup( "Treemaps" );
 
     _ambientLight	= config->readNumEntry( "AmbientLight"		,  DefaultAmbientLight );
@@ -148,7 +148,7 @@ KTreemapView::readConfig()
 
 
 TQColor
-KTreemapView::readColorEntry( KConfig * config, const char * entryName, TQColor defaultColor )
+KTreemapView::readColorEntry( TDEConfig * config, const char * entryName, TQColor defaultColor )
 {
     return config->readColorEntry( entryName, &defaultColor );
 }
@@ -410,7 +410,7 @@ KTreemapView::rebuildTreemap( KFileInfo *	newRoot,
     if ( ! canvas() )
     {
 	TQCanvas * canv = new TQCanvas( TQT_TQOBJECT(this) );
-	CHECK_PTR( canv );
+	TQ_CHECK_PTR( canv );
 	setCanvas( canv );
     }
 
@@ -740,6 +740,6 @@ KTreemapSelectionRect::highlight( KTreemapTile * tile )
     }
 }
 
-
+#include "ktreemapview.moc"
 
 // EOF
